Package: fairmetrics
Title: Fairness Evaluation Metrics with Confidence Intervals for Binary
        Protected Attributes
Version: 1.0.8
Authors@R: 
    c(
    person("Jianhui", "Gao", email = "jianhui.gao@mail.utoronto.ca", role = c("aut"),comment = c(ORCID = "0000-0003-0915-1473")),
    person("Benjamin", "Smith", email = "benyamin.smith@mail.utoronto.ca", role = c("aut","cre"), comment = c(ORCID = "0009-0007-2206-0177")),
    person("Benson", "Chou", email = "benson.chou@mail.utoronto.ca", role = c("aut"), comment = c(ORCID = "0009-0007-0265-033X")),
    person("Jessica", "Gronsbell", email = "j.gronsbell@utoronto.ca", role = c("aut"), comment = c(ORCID = "0000-0002-5360-5869"))
    )
Description: A collection of functions for computing fairness metrics for machine learning and statistical models, including confidence intervals for each metric. The package supports the evaluation of group-level fairness criterion commonly used in fairness research, particularly in healthcare for binary protected attributes. It is based on the overview of fairness in machine learning written by Gao et al (2025) <doi:10.1002/sim.70234>.
Imports: stats
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.2
Suggests: dplyr, magrittr, corrplot, randomForest, pROC,
        SpecsVerification, knitr, rmarkdown, testthat, kableExtra,
        naniar
Config/testthat/edition: 3
Depends: R (>= 3.5.0)
LazyData: true
URL: https://jianhuig.github.io/fairmetrics/
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-04-16 14:25:48 UTC; ben29
Author: Jianhui Gao [aut] (ORCID: <https://orcid.org/0000-0003-0915-1473>),
  Benjamin Smith [aut, cre] (ORCID:
    <https://orcid.org/0009-0007-2206-0177>),
  Benson Chou [aut] (ORCID: <https://orcid.org/0009-0007-0265-033X>),
  Jessica Gronsbell [aut] (ORCID:
    <https://orcid.org/0000-0002-5360-5869>)
Maintainer: Benjamin Smith <benyamin.smith@mail.utoronto.ca>
Repository: CRAN
Date/Publication: 2026-04-16 15:00:02 UTC
Built: R 4.5.2; ; 2026-04-17 09:07:04 UTC; unix
