# Generated by roxygen2: do not edit by hand

export(eval_acc_parity)
export(eval_bs_parity)
export(eval_cond_acc_equality)
export(eval_eq_odds)
export(eval_eq_opp)
export(eval_neg_class_bal)
export(eval_neg_pred_parity)
export(eval_pos_class_bal)
export(eval_pos_pred_parity)
export(eval_pred_equality)
export(eval_stats_parity)
export(eval_treatment_equality)
export(get_fairness_metrics)
importFrom(stats,qnorm)
importFrom(stats,sd)
